@@ -21,9 +21,11 @@ def _pad_key(key):
 
 def encrypt(msg, key=None, url_safe=False):
     if not key:
-        return msg.encode('utf-8')
+        return msg
     else:
-        key = _pad_key(key).encode('utf-8')
+        key = _pad_key(key)
+        if not isinstance(key, bytes):
+            key = key.encode('utf-8')
 
     msg = (msg + '$').encode('utf-8')
     padded_msg = msg.ljust((len(msg) // 16 + 1) * 16)
@@ -33,14 +35,19 @@ def encrypt(msg, key=None, url_safe=False):
         encoded = base64.b64encode(encrypted, altchars=b'-_')
     else:
         encoded = base64.b64encode(encrypted)
-    return encoded
+    return encoded.decode('utf-8')
 
 
 def decrypt(encoded, key=None, url_safe=False):
     if not key:
-        return encoded.decode('utf-8')
+        if isinstance(encoded, bytes):
+            return encoded.decode('utf-8')
+        else:
+            return encoded
     else:
-        key = _pad_key(key).encode('utf-8')
+        key = _pad_key(key)
+        if not isinstance(key, bytes):
+            key = key.encode('utf-8')
 
     cipher = AES.new(key, AES.MODE_ECB)
     if url_safe:
